# In[20]:
import os, os.path
import datetime
# FireWorks functionality
from fireworks.utilities.dagflow import DAGFlow, plot_wf
from fireworks import Firework, LaunchPad, Workflow
from fireworks.utilities.filepad import FilePad


timestamp = datetime.datetime.now()
yyyymmdd = timestamp.strftime('%Y%m%d')
yyyy_mm_dd = timestamp.strftime('%Y-%m-%d')

# plotting defaults
visual_style = {}

# generic plotting defaults
visual_style["layout"] = 'kamada_kawai'
visual_style["bbox"] = (1600, 1200)
visual_style["margin"] = [400, 100, 400, 200]

visual_style["vertex_label_angle"] = -3.14/4.0
visual_style["vertex_size"] = 8
visual_style["vertex_shape"] = 'rectangle'
visual_style["vertex_label_size"] = 10
visual_style["vertex_label_dist"] = 4

# edge defaults
visual_style["edge_color"] = 'black'
visual_style["edge_width"] = 1
visual_style["edge_arrow_size"] = 1
visual_style["edge_arrow_width"] = 1
visual_style["edge_label_size"] = 8

# In[22]:

# prefix = '/mnt/dat/work/testuser/indenter/sandbox/20191110_packmol'
prefix = '/home/jotelha/git/jlhphd'
work_prefix = '/home/jotelha/tmp/{date:s}_fw/'.format(date=yyyymmdd)
try:
    os.makedirs(work_prefix)
except:
    pass
os.chdir(work_prefix)

# the FireWorks LaunchPad
lp = LaunchPad.auto_load() #Define the server and database
# FilePad behaves analogous to LaunchPad
fp = FilePad.auto_load()

# In[]:

# DPD equilibration
index_file_input_datasets = [{'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'uuid': '015048d4-ca53-4683-a1fd-9fa34e596f85'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'uuid': 'ead6d394-9f97-478a-b45b-392b09ea2ff9'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 0.0,
  'uuid': 'dc682df5-12f3-4a5f-998e-d9932983d889'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -25.0,
  'uuid': 'f4d4222e-5222-4f70-b055-7bb9f43f8d50'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'uuid': 'b66eea97-d276-4814-95b2-f88b4e6dfbb7'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'uuid': '31492349-245d-4287-b39e-e53b34fa8236'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'uuid': '66e85886-cb11-4ddd-b51f-e62fa6f1ec16'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'uuid': '1d185094-2dd1-4930-b2cf-d92ad64290ac'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'uuid': '4e3eae9e-6ea0-42bd-a9bd-218983dbab4e'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'uuid': 'd607ea9e-83df-4aa0-afa1-e408258f8a97'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'uuid': 'ceebbc45-7360-4732-ae2f-810ebf8674d1'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'uuid': '704d59f5-6856-4a5b-9ba6-1b2673b86486'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'uuid': 'cdc95c01-f3c3-4400-8f45-339c065ca0e8'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -50.0,
  'uuid': '12601538-8a94-49db-afef-e65706a9f712'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'uuid': '762f9596-5de5-405e-8507-d7c605985321'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'uuid': '2890f7fd-e938-48b1-aaae-f7c6db063dba'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 0.0,
  'uuid': '5b5f0af5-473e-4f07-a890-1c6d34904b93'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'uuid': '6fb7c45f-210f-4de5-8b1f-7527d5a106a9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'uuid': '9e468f7f-d27c-4e96-9a83-0b933481c4bf'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'uuid': 'a2e83a60-99e4-4ee9-a52f-c051858f7bfb'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'uuid': 'f22269f3-6e3b-481a-b3c3-fbafa2fb1804'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'uuid': 'a9101e05-7076-4dee-9b90-70484b7d2f12'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -25.0,
  'uuid': 'e419da6c-23ec-4d3b-bf33-0754fda8c5a2'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'uuid': 'cdc04b4d-7197-4788-aeba-f85d57b31664'}]

    
probe_on_substrate_input_datasets = [
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 50.0,
  'uuid': '7154ff2b-3d4a-44a1-a005-fa7a4c0c64dc'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 10.0,
  'uuid': '70fbc1a3-12be-4066-8b5d-873710240394'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 5.0,
  'uuid': '3c3043f7-913d-441a-a42c-428ee58f5f4f'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 15.0,
  'uuid': 'defa76ed-ffa8-41bc-a5f0-a9dfe5663cd5'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 30.0,
  'uuid': 'b8a0c747-d213-4d9b-831b-a75283abbf79'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 40.0,
  'uuid': '626f5916-f7d9-475b-9e54-ffe1d0e7083d'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 0.0,
  'uuid': 'd3bac42e-9575-45b1-b8bb-2514a1faa3a9'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 25.0,
  'uuid': '67acd271-553f-4c0e-b98a-d4d1708963b5'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 35.0,
  'uuid': '3294d57e-679b-44ec-b91b-7aafb4ab6033'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 20.0,
  'uuid': '062962e0-59f4-4589-a77d-b8889e9d6b41'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 50.0,
  'distance': 45.0,
  'uuid': 'c96366c5-3383-4347-bdca-a8186da1dc89'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 40.0,
  'uuid': '463bb0c6-61b9-4b8b-a18a-6436ea35e49c'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 25.0,
  'uuid': '7ae8179e-a706-4776-9744-765867498fbe'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 5.0,
  'uuid': '3d85e181-57fe-4802-8154-18f45238ff88'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 10.0,
  'uuid': '3649f180-5ece-4a87-9b25-0c2d2e540ace'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 15.0,
  'uuid': 'f89598ad-54bf-42b1-8d15-3602aa53f2e0'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 30.0,
  'uuid': '4af7179e-a736-4a06-ab3a-dfad881f668f'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 45.0,
  'uuid': 'f74003b0-5208-4a13-8b5c-2342c1ed93b0'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 50.0,
  'uuid': '7dbde2e2-f53f-4a40-9958-34a37607704d'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 20.0,
  'uuid': '66db4849-cd93-496f-825b-54d01292946d'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 35.0,
  'uuid': '8b497d6b-79fd-48cf-b8f9-c0b15167a525'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': -50.0,
  'distance': 0.0,
  'uuid': '5807ad67-adba-44fc-8811-310c40e860d4'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 15.0,
  'uuid': '78cd0ae2-77c0-426f-899d-56e1bb6faea7'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 45.0,
  'uuid': '66ead8bf-065c-4512-b755-76c943696c14'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 5.0,
  'uuid': '5e03334f-bb15-4df6-8e03-85049f0f75e9'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 35.0,
  'uuid': '8c1cb2d0-7a69-4bf3-bb76-86c8965f775f'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 30.0,
  'uuid': 'd6042d4e-25b1-435c-93f2-d9b72a3bc981'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 25.0,
  'uuid': '1b2676b5-f6fb-40fb-ac26-0c72851e7df3'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 50.0,
  'uuid': 'b92acf2c-2088-4849-a914-12e41dedda22'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 40.0,
  'uuid': '69f322f3-82e9-4213-b8ae-9fb8e150becd'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 20.0,
  'uuid': 'e836244d-a69a-4429-b217-581e84d73e2c'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 10.0,
  'uuid': '77958152-9f0a-4658-bd6b-03e762156821'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 50.0,
  'distance': 0.0,
  'uuid': '9c0228e4-426d-430f-bba5-4ebecd829c2e'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 50.0,
  'uuid': 'f0c43420-f63b-4726-8d79-400b1d88c59b'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 25.0,
  'uuid': '04c04b69-9edf-4cb5-8bb6-4606ba4ed44f'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 30.0,
  'uuid': '88cf0a98-9a39-4dda-9955-3aa36dff7740'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 15.0,
  'uuid': '6d2684e7-c107-43d0-8ac8-39d8c3c64f90'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 10.0,
  'uuid': 'c82cffea-f0c1-49be-80ec-f78266fd8bce'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 0.0,
  'uuid': '8b19ca2a-3f93-427e-b411-167f3a16b0ba'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 20.0,
  'uuid': 'ed07c4b5-e65d-4e50-ba42-9dce57af8da7'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 5.0,
  'uuid': '619f80df-d115-4a46-b7f4-dc2b6ab4bce6'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 40.0,
  'uuid': '2e0b9785-f5de-48c7-ae49-b096b681bc65'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 35.0,
  'uuid': 'f427c115-0f95-4fa2-a6d0-a057df4d054e'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': -25.0,
  'distance': 45.0,
  'uuid': '7c475681-d810-4c60-b3f8-a6d6db8f5479'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 40.0,
  'uuid': '9a55189f-0e27-482d-ab7d-5158cdae3c8c'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 35.0,
  'uuid': 'a08bffc6-e44d-42a1-b3cb-938b88277c14'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 10.0,
  'uuid': 'a3046662-8dd9-4d2d-b916-9b4479f08aa1'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 30.0,
  'uuid': '5d6ac097-086a-4932-8925-832c80d053ee'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 15.0,
  'uuid': '1531bd1a-7195-47f8-ac0d-d9d1304f0aab'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 45.0,
  'uuid': '410e7eef-531a-420c-a278-3c1601b2e458'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 50.0,
  'uuid': '67af7304-ea6d-4c8b-8731-32681946d77b'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 5.0,
  'uuid': 'ef73cddb-b6d1-4d03-8f91-dd26568cd65d'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 20.0,
  'uuid': 'e51c3702-2ffe-4062-85d2-9d6a4ce715b1'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 25.0,
  'uuid': 'bb26d167-4092-4c99-9aa0-664f9aab4641'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': -50.0,
  'distance': 0.0,
  'uuid': '43813b69-3d2a-4b73-bd6c-c0374a547cc5'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 45.0,
  'uuid': '17f1717d-16f3-4de0-85a6-3200b5bed44a'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 5.0,
  'uuid': '790ad875-f749-4d17-ad34-7d472a743d6c'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 25.0,
  'uuid': 'c286530e-8ff9-4ecf-b5cb-7f81c13fa3d6'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 20.0,
  'uuid': 'daf93b52-5a4c-4100-8608-fb8aa647ee51'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 0.0,
  'uuid': '5b4e291c-7eb0-4104-9e6a-02214cab1041'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 50.0,
  'uuid': '47992bfb-a5b5-4625-b809-a56f38ee28a4'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 10.0,
  'uuid': 'e4b2afcc-2f44-4e4b-9de1-86a6f4d69f2d'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 40.0,
  'uuid': '069c25e2-58f2-47ff-9ce0-6ff6df444825'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 35.0,
  'uuid': '0d1a5745-6817-4b0c-952d-793c659bcc94'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 15.0,
  'uuid': '1c122f8f-5a90-47c8-a080-63337d83fe3d'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 25.0,
  'distance': 30.0,
  'uuid': '50e979ed-6125-4dd8-943b-5c710480bd21'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 45.0,
  'uuid': '7ff6c679-28fd-4b5c-b2ec-eefe0a99b7bb'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 35.0,
  'uuid': '9520154f-98f1-4a44-8a6a-f0b484d8e0f9'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 25.0,
  'uuid': '7f7668ab-2ff7-43c5-b976-88cd33aaa038'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 10.0,
  'uuid': '39be67b9-00a4-45ac-b7ad-4dffab1c8780'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 30.0,
  'uuid': 'b5feedfb-88bf-40d6-aab2-f215a5b9d6de'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 15.0,
  'uuid': '23577c3b-2c6b-44b6-9902-0371c1640b05'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 20.0,
  'uuid': 'a63f35fd-97b2-41af-9a3f-81d999e0b18e'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 5.0,
  'uuid': '79310291-4991-49e4-b4a3-419f20412d6b'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 50.0,
  'uuid': 'e6d22630-63f4-40a1-8e56-a358e6cb5105'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 0.0,
  'uuid': '3c8681d6-f1f5-4e6e-9ded-5ff870cb4345'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 25.0,
  'distance': 40.0,
  'uuid': 'e3a8e179-90c6-44b5-b461-1d9819474fcc'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 0.0,
  'uuid': '7bea8c92-71de-415d-b7a3-a54b90e390a9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 20.0,
  'uuid': '473ab7e2-078c-43e5-b328-015df30507c9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 50.0,
  'uuid': '671b35b7-cc4c-4572-9ad7-ff0406f9c1d9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 45.0,
  'uuid': '22bce38a-dd41-45d4-8765-239e1e4a8cb9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 5.0,
  'uuid': '5f1f3cc1-2749-4c9d-9e88-d9f313987bbb'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 10.0,
  'uuid': 'b644c4f5-b4a4-4bec-8b72-1fc40f6e3ec5'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 40.0,
  'uuid': '567db47f-9c4a-4d4b-94d6-6584f7938a39'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 30.0,
  'uuid': '1689ad1a-2acb-4811-b5db-9f4808193db6'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 35.0,
  'uuid': '411d1ae9-2882-4994-a8e7-4baaf1dc3ae1'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 25.0,
  'uuid': '5c44a6f3-32c6-4b5b-8660-ac86c6b03336'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 50.0,
  'distance': 15.0,
  'uuid': 'a6fea7e1-5937-459e-bac1-5d9c50ac9845'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 50.0,
  'uuid': '9504ac26-0a19-4681-975f-2db752571ad9'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 30.0,
  'uuid': '86f66f8c-1e54-4e3d-976c-3d2de05a89f5'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 15.0,
  'uuid': '1a43958a-7002-4e92-98e6-1e102d140307'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 35.0,
  'uuid': 'a669d8c8-eade-4c63-9fe5-80be45165495'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 10.0,
  'uuid': 'a9a1fa4b-91a5-42b1-bb95-cd9d43affcf8'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 25.0,
  'uuid': '95161589-58e3-4e89-b425-e0ca605083a6'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 5.0,
  'uuid': 'aa8eba3c-13e1-4458-aa35-810634958e10'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 40.0,
  'uuid': 'f9eeb241-dbd2-4fdc-a2af-b48979961898'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 45.0,
  'uuid': '8c2a5cb2-38e4-422e-a111-099e236e9c4e'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 20.0,
  'uuid': '09d3f9fa-fd2e-44cd-8844-5e9b3d60acbb'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 0.0,
  'distance': 0.0,
  'uuid': '06011e88-b320-43be-9e55-dc1f31328b63'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 45.0,
  'uuid': 'da3d15a8-10dc-42f6-b53e-422354b54737'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 30.0,
  'uuid': '47ca37fa-a421-4d4e-86d7-10c323c25a1a'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 5.0,
  'uuid': '73fabfc3-bfc5-4133-bffe-419e4501120a'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 0.0,
  'uuid': '33bd47ab-2aa2-40ca-8eba-56490885f106'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 10.0,
  'uuid': '7ecab380-8934-4f4a-9d2d-ac6a8727f081'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 40.0,
  'uuid': 'bdd2e39d-adc5-4f45-8d61-b4990bf05ce0'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 20.0,
  'uuid': '23fae367-6647-4415-b324-fdf5eda17e0d'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 35.0,
  'uuid': '3a7f7e04-8b04-4d4b-a7a8-de0aae37d101'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 15.0,
  'uuid': 'c81f5065-abd3-4e56-8daa-ba0f71d6b368'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 50.0,
  'uuid': '16d61830-d871-4e67-8128-25f741881019'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -25.0,
  'distance': 25.0,
  'uuid': 'eb9211d6-41af-4bef-a485-7fc0d033178e'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 40.0,
  'uuid': '2a33c0d9-5c57-45c6-9c29-5fe2200cbf9c'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 15.0,
  'uuid': 'eda2230a-0e93-4240-9ce4-f326e23a7141'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 25.0,
  'uuid': '4aced97f-0b0d-4c5f-9bd9-5dcb8d57621e'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 30.0,
  'uuid': '52db1df6-dad2-484e-adb8-068fa359e640'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 50.0,
  'uuid': '0cc299c5-b81c-43b0-909a-0ccff4164673'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 0.0,
  'uuid': '8baafd91-183a-44f9-811b-c1c269b7e23a'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 10.0,
  'uuid': '1df3b6fe-e577-41ce-8992-6b97336b1986'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 35.0,
  'uuid': '4e930b65-f5af-4c20-9d7c-2fc9126b59f1'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 20.0,
  'uuid': 'd021efb4-6184-488c-bc77-c5d6c07bddf1'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 5.0,
  'uuid': '4d4b35fe-80b9-496b-9d2a-a5a25035db21'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -25.0,
  'distance': 45.0,
  'uuid': '7e78d2e1-d4a0-4273-9855-e60548022781'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 15.0,
  'uuid': '2ffa3b91-5576-471d-a105-bbfb0e29ab7c'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 30.0,
  'uuid': 'c36e3273-a6b2-4594-8788-5f3a1fab6196'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 20.0,
  'uuid': 'ba3d7a9d-e407-45fb-8193-32d38ce61afd'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 35.0,
  'uuid': '592bb7a5-29fe-4387-b968-dc2961a755dd'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 45.0,
  'uuid': '097f4f1b-17f0-4918-b67e-a03f9f267d13'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 25.0,
  'uuid': '97a97435-9bd7-4c70-9217-88da4886b8cd'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 10.0,
  'uuid': '22dab8e6-d37a-4659-b884-a4d29ae14c74'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 40.0,
  'uuid': '780da678-504c-4e82-acad-2f365b69b577'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 0.0,
  'uuid': '15ec7914-bd03-4cbe-8372-9c94c5cef3f2'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 5.0,
  'uuid': 'b304eaa2-00f5-4e1a-a565-27d88113821c'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': 25.0,
  'distance': 50.0,
  'uuid': 'aeb631a3-f9cf-4703-b704-4354d5a03c60'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 5.0,
  'uuid': '0b44da46-cbd5-4d98-b6a0-fd86b17f70c4'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 25.0,
  'uuid': '5d781434-3d64-443a-9960-9212d3040c16'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 35.0,
  'uuid': '4f9cb450-7fde-4672-a962-a05c71354f99'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 40.0,
  'uuid': '10212605-2165-4185-8e4c-391f37a2de6f'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 10.0,
  'uuid': '9f27fd49-57e4-418f-9aae-f73aa7fadf11'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 50.0,
  'uuid': 'c1c13fac-b522-4a70-bd83-ccea6d5cef81'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 20.0,
  'uuid': 'ef64c5d5-df59-4cb2-96ca-9ca4dfcb93e7'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 15.0,
  'uuid': '59fea244-f828-44ca-ba66-47b826070d47'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 30.0,
  'uuid': '86d5aeca-0059-4c38-bf36-c02d290291a6'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 0.0,
  'uuid': 'a320b212-5ff7-4583-9cf3-5d1da4a0d0d6'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 50.0,
  'distance': 45.0,
  'uuid': '6c49fa19-e1a1-4694-bae2-9dbfc29eb273'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 50.0,
  'uuid': 'c3f15f76-848f-4d74-bc0d-4f62e6e4e2fb'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 15.0,
  'uuid': 'ed50e45a-bbe5-4371-ac7c-8d8277b91f0a'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 45.0,
  'uuid': 'c759fd03-2ebf-4a77-b834-89dc2ae2960e'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 0.0,
  'uuid': 'cd7b3a04-ae51-4966-9e28-db51deea91cd'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 40.0,
  'uuid': '2e126a0a-3f40-4a92-be2d-d4a0ffe0c7ab'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 5.0,
  'uuid': 'be38bf8c-365a-451e-8356-b0bee620d9c9'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 25.0,
  'uuid': 'd95faf95-94ac-4610-b398-1768fdc8fd8e'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 35.0,
  'uuid': '9d6ecd67-041b-451c-974f-d1366e33f60e'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 20.0,
  'uuid': 'ac2c7cb5-ba5e-4941-84ff-295353a626b2'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 10.0,
  'uuid': '61fb7430-7836-4055-a88b-7ab0dc18cce4'},
 {'nmolecules': 916,
  'x_shift': 0.0,
  'y_shift': 0.0,
  'distance': 30.0,
  'uuid': '6b8070d5-5415-4eb4-8b9a-920949464467'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 45.0,
  'uuid': '57434e94-d076-449d-8ebc-3118e8aab635'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 5.0,
  'uuid': '3c3c3d51-ef5c-4607-8bb4-095cff195e9f'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 20.0,
  'uuid': 'c524d6f6-eb3e-4250-9dd5-7b702e0dfcda'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 0.0,
  'uuid': '2c05f6ad-d57c-473c-80dd-10e3e8426835'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 40.0,
  'uuid': '4150c310-45aa-4319-b4de-cf5cec43fa96'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 50.0,
  'uuid': '76616a7e-37b6-4fa2-94c0-48a97b918d3c'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 15.0,
  'uuid': '30765c4c-2edd-4cd1-9771-8491d1f01305'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 25.0,
  'uuid': '73fb5905-5508-4dfc-aa7c-4bd803d53268'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 10.0,
  'uuid': 'a155bb86-058b-4589-88b5-15853d4ea2d5'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 35.0,
  'uuid': 'bed326a8-3f0e-4582-91f3-5f3e54d54c65'},
 {'nmolecules': 916,
  'x_shift': -50.0,
  'y_shift': 25.0,
  'distance': 30.0,
  'uuid': 'db6c6c0d-d950-490d-8188-56cc398e2496'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 0.0,
  'uuid': '30bd25dc-5e19-4c9f-a7fc-dd7e077d7ca6'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 15.0,
  'uuid': 'd32b602b-320c-4ca5-a004-2d62f1c5cf88'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 45.0,
  'uuid': 'ea3ff95c-4c83-4885-9d1e-c42c39615aa8'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 20.0,
  'uuid': '52b19da0-36d1-4884-a6a2-791fa21a004c'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 40.0,
  'uuid': '544cc58d-2a33-4db0-80ee-f439f9f5ce78'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 30.0,
  'uuid': 'f390d4b4-29e1-43ed-a1c7-52e715030440'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 10.0,
  'uuid': '3b695c8c-49f7-4ecd-8e2a-45481785f33b'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 25.0,
  'uuid': 'ff8e02c0-8f68-42f9-8f29-257661b6be45'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 50.0,
  'uuid': '36a2e222-e23e-4d6a-88da-d990b7e95a9a'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 5.0,
  'uuid': '115cdd44-a6e3-4ace-b342-0f6ba858caad'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': 0.0,
  'distance': 35.0,
  'uuid': '6f50fae1-607b-47e5-949d-20c0d12dd0aa'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 45.0,
  'uuid': 'f12fe0fe-844e-4f56-8d18-8c99c70a322b'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 5.0,
  'uuid': 'cb232a92-e73e-4f14-bd62-d18a50bc0ec9'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 20.0,
  'uuid': 'f49745df-ae92-4a69-b3c6-0a1f5749c30d'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 15.0,
  'uuid': '6ce11dea-1960-4541-b1c2-55b9ff8593b1'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 30.0,
  'uuid': '6f929ba8-0a3b-4ccd-935e-4a0a66497de4'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 35.0,
  'uuid': '4e1d5202-69f6-4a8f-9898-6e3840b044cf'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 0.0,
  'uuid': 'd589cf9f-b5c2-411c-94ce-aa0decabb30c'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 40.0,
  'uuid': 'e81a659c-26a5-48a7-b747-0f6d416a66eb'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 50.0,
  'uuid': '79ee6d35-b78f-4597-90ff-dded42c9fd0d'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 10.0,
  'uuid': 'f2a410d3-8ab7-4d06-8131-b58a7b909a97'},
 {'nmolecules': 916,
  'x_shift': -25.0,
  'y_shift': -50.0,
  'distance': 25.0,
  'uuid': '5f3c6773-cf1a-4072-8ab9-d9740dd9dd41'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 50.0,
  'uuid': '7b52a562-b5ea-4b0b-aa32-761b9937e7c3'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 5.0,
  'uuid': '052f925f-b67a-43bd-ae02-026495316fc6'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 25.0,
  'uuid': '3c24ab98-6bac-4602-aae2-26357bba88f3'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 35.0,
  'uuid': 'e9e3efc4-e47e-420a-9d83-3dca25ab4ab9'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 15.0,
  'uuid': '08afe369-52d5-4026-be1d-dd5289380113'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 20.0,
  'uuid': '95778797-b4e0-49d7-97fc-b9851db141a8'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 40.0,
  'uuid': '338d3ac5-dbe5-4645-a18b-ecb685f69c58'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 10.0,
  'uuid': 'b67372a9-3273-4d33-ae09-37cf4be8f919'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 45.0,
  'uuid': '35187219-cf25-4a00-906e-d09c5734f5e7'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 30.0,
  'uuid': '1cfdaf5a-52a6-44e8-93de-68394ebc6251'},
 {'nmolecules': 916,
  'x_shift': 50.0,
  'y_shift': 50.0,
  'distance': 0.0,
  'uuid': '6a33c8e7-877c-447e-82bc-7d77cf222b45'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 50.0,
  'uuid': 'f31d0451-a8f0-4438-a640-4fd5a056efa1'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 30.0,
  'uuid': '29fbacd3-c558-44ad-95a8-7a282ef74eb8'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 35.0,
  'uuid': '98828c2f-f5a1-45c6-a2e1-505b32e26364'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 40.0,
  'uuid': '793e7af7-7d72-4706-9f67-894b9e7e5bee'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 20.0,
  'uuid': '01092589-acd4-470e-a740-d75c79e1d7db'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 45.0,
  'uuid': '997d62ad-cedb-48d7-a291-16fed2f2840c'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 0.0,
  'uuid': 'c591c260-7efb-411f-ac74-8652521ff480'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 15.0,
  'uuid': 'a6b1ee6a-ff73-4570-ba51-c0ae68d88f16'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 25.0,
  'uuid': '6d28460f-3e65-4288-b909-77f91d3685d7'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 5.0,
  'uuid': 'b14af2b2-a29b-48c7-af1e-2dfe805a961b'},
 {'nmolecules': 916,
  'x_shift': 25.0,
  'y_shift': -50.0,
  'distance': 10.0,
  'uuid': '0cbdb249-efdb-4495-9d22-3fba84de517a'}
]

index_file_input_datasets_index_map = { (d["x_shift"], d["y_shift"]): i for i, d in enumerate(index_file_input_datasets) }

for d in probe_on_substrate_input_datasets:
    d['index_file_uuid'] = index_file_input_datasets[ index_file_input_datasets_index_map[(d['x_shift'],d['y_shift'])]]['uuid']
    
probe_on_substrate_input_datasets_index_map = { (d["x_shift"], d["y_shift"], d["distance"]): i for i, d in enumerate(probe_on_substrate_input_datasets) }

parameter_dict_list = [{**d} for d in probe_on_substrate_input_datasets]
# In[20]:

# SDS on Au(111)
from jlhpy.utilities.wf.probe_on_substrate.chain_wf_probe_on_substrate_lateral_sliding import WrapJoinAndDPDEquilibration

from jlhpy.utilities.wf.mappings import sds_lammps_type_atom_name_mapping
# remove all project files from filepad:
#     fp.delete_file_by_query({'metadata.project': project_id})

# index = probe_on_substrate_input_datasets_index_map[0,0,25.0]
# In[25]:
    
project_id = '2021-12-27-sds-on-au-111-probe-on-substrate-wrap-join-and-dpd-equilibration'

wf_list = []
# for c, substrate_uuid, probe_uuid in probe_on_substrate_input_datasets:
# c = 0.03
for p in parameter_dict_list:
    wfg = WrapJoinAndDPDEquilibration(
        project_id=project_id,
        
        files_in_info={
            'data_file': {
                'query': {'uuid': p['uuid']},
                'file_name': 'default.lammps',
                'metadata_dtool_source_key': 'step_specific',
                'metadata_fw_dest_key': 'metadata->step_specific',
                'metadata_fw_source_key': 'metadata->step_specific',
            },
            'index_file': {
                'query': {'uuid': p['index_file_uuid']},
                'file_name': 'groups.ndx',
                'metadata_dtool_source_key': 'system',
                'metadata_fw_dest_key': 'metadata->system',
                'metadata_fw_source_key': 'metadata->system',
            }
        },
        integrate_push=True,
        description="SDS on Au(111) probe on substrate wrap-join and DPD equilibration after frame extraction",
        owners=[{
            'name': 'Johannes Laurin Hörmann',
            'email': 'johannes.hoermann@imtek.uni-freiburg.de',
            'username': 'fr_jh1130',
            'orcid': '0000-0001-5867-695X'
        }],
        infile_prefix=prefix,
        machine='juwels',
        mode='production',
        system = {},
        step_specific={
            'wrap_join' : {
                'type_name_mapping': sds_lammps_type_atom_name_mapping
            },
            'equilibration': {
                'dpd': {
                    'freeze_substrate_layer': 14.0,  # freeze that slab at the substrate's bottom
                    'rigid_indenter_core_radius': 12.0,  # freeze that sphere at the core of the indenter
                    'temperature': 298.0,
                    'steps': 10000,
                    'netcdf_frequency': 100,
                    'thermo_frequency': 100,
                    'thermo_average_frequency': 100,
                    'restart_frequency': 100,
                    
                    'ewald_accuracy': 1.0e-4,
                    'coulomb_cutoff': 8.0,
                    'neigh_delay': 2,
                    'neigh_every': 1,
                    'neigh_check': True,
                    'skin_distance': 3.0,
                    
                    'max_restarts': 5,
                },
            },
            'dtool_push': {
                'dtool_target': '/p/project/hfr21/hoermann4/dtool/PRODUCTION/2021-12-27-sds-on-au-111-probe-on-substrate-wrap-join-and-dpd-equilibration',
                'remote_dataset': None,
            }
        }
    )
    fp_files = wfg.push_infiles(fp)
    wf = wfg.build_wf()
    wf_list.append(wf)
    
# In[]:
 
    
# for wf in wf_list:
#    lp.add_wf(wf)

# 2021-12-27: submitted 0:20, failed due to 6 h walltime on JUWELS
# 2021-12-28: submitted 21
# 2021-12-31: submitted 21, [22:]
